@@ -2,7 +2,6 @@ import argparse
 import os
 
 from jenesis.config import Config
-from jenesis.contracts.detect import detect_contracts
 
 
 def add_contract_command(parser):
@@ -10,6 +9,7 @@ def add_contract_command(parser):
     add_contract_cmd = parser.add_parser("contract")
     add_contract_cmd.add_argument("template", help="The name of the template to use")
     add_contract_cmd.add_argument("name", help="The name of contract to create")
+    add_contract_cmd.add_argument('-d','--deployments', nargs='+', help='contract deployments')
     add_contract_cmd.add_argument(
         "-b", "--branch", help="The name of the branch that should be used"
     )
@@ -17,6 +17,7 @@ def add_contract_command(parser):
 
 
 def run_add_contract(args: argparse.Namespace):
+
     template = args.template
     name = args.name
     branch = args.branch
@@ -24,9 +25,10 @@ def run_add_contract(args: argparse.Namespace):
     project_root = os.path.abspath(os.getcwd())
     contract_root = os.path.join(project_root, "contracts", name)
 
+    cfg = Config.load(project_root)
+
     # check that we are actually running the command from the project root
     if not os.path.exists(os.path.join(project_root, "jenesis.toml")):
-        # pylint: disable=all
         print("Please run command from project root")
         return False
 
@@ -35,25 +37,16 @@ def run_add_contract(args: argparse.Namespace):
         print(f'Contract "{name}" already exists')
         return False
 
-    Config.add_contract(contract_root, template, name, branch)
+    selected_contract = Config.add_contract(project_root, template, name, branch)
 
-    contracts = detect_contracts(project_root)
+    if selected_contract is None:
+        return False
 
-    selected_contract = ""
-    for contract in contracts:
-        if contract.name == name:
-            selected_contract = contract
-            continue
+    deployments = args.deployments or [args.name]
 
-    if selected_contract == "":
-        print("Contract not found in project")
-        return
-
-
-    cfg = Config.load(project_root)
-
-    for profile in cfg.profiles.keys():
-        network_name = cfg.profiles[profile].network.name
-        Config.update_project(os.getcwd(), profile, network_name, selected_contract)
+    for (profile_name, profile) in cfg.profiles.items():
+        network_name = profile.network.name
+        for deployment in deployments:
+            Config.update_project(os.getcwd(), profile_name, network_name, selected_contract, deployment)
 
     return True
