@@ -3,9 +3,10 @@ import os
 
 from cosmpy.aerial.client import LedgerClient
 from jenesis.config import Config
-from jenesis.contracts.detect import detect_contracts
+from jenesis.contracts.detect import parse_contract
 from jenesis.contracts.monkey import MonkeyContract
 from jenesis.network import Network
+from jenesis.network import network_context
 import toml
 
 def run(args: argparse.Namespace):
@@ -28,32 +29,27 @@ def run(args: argparse.Namespace):
 
     selected_profile = cfg.profiles[profile_name]
 
-    contracts = detect_contracts(project_path)
-
-    selected_contract = ""
-    for contract in contracts:
-        if contract.name == args.contract:
-            selected_contract = contract
-            continue
-
-    if selected_contract == "":
-        print('Contract not found in project')
+    if args.deployment not in selected_profile.deployments:
+        print('Deployment not found in project')
         return 1
 
+    deployment = selected_profile.deployments[args.deployment]
+
     client = LedgerClient(selected_profile.network)
+    contract_to_attach = parse_contract(project_path, deployment.contract)
 
-    contract = MonkeyContract(selected_contract, client, args.address)
-    code_id = contract.code_id
-    digest = contract.digest.hex()
-
-    data = toml.load("jenesis.toml") 
-
+    data = toml.load("jenesis.toml")
     network = Network(**data["profile"][profile_name]["network"])
 
-    Config.update_project(project_path, profile_name, network.name, selected_contract)
+    with network_context(network, cfg.project_name, profile_name):
+        contract = MonkeyContract(contract_to_attach, client, args.address)
+        code_id = contract.code_id
+        digest = contract.digest.hex()
+
+    Config.update_project(project_path, profile_name, network.name, contract_to_attach, deployment.name)
 
     cfg.update_deployment(
-        selected_profile.name, args.contract, digest, code_id, args.address
+        selected_profile.name, deployment.name, digest, code_id, args.address
     )
     cfg.save(project_path)
     return 0
@@ -61,12 +57,12 @@ def run(args: argparse.Namespace):
 
 def add_attach_command(parser):
     attach_cmd = parser.add_parser("attach")
-    attach_cmd.add_argument("contract", help="Contract name")
+    attach_cmd.add_argument("deployment", help="Deployment name")
     attach_cmd.add_argument("address", help="Contract address")
     attach_cmd.add_argument(
         "-p",
         "--profile",
         default=None,
-        help="Profile where the contract will be attached",
+        help="Profile where deployment will be attached to",
     )
     attach_cmd.set_defaults(handler=run)
\ No newline at end of file
