@@ -1,9 +1,16 @@
 import argparse
-
+import os
 from jenesis.config import Config
 
 
 def run(args: argparse.Namespace):
+    project_path = os.getcwd()
+
+    # check if the project has been already initialized
+    if os.path.exists(os.path.join(project_path, args.project)):
+        print("Project already exists")
+        return
+
     Config.create_project(args.project, args.profile, args.network)
 
 def add_new_command(parser):
