@@ -16,8 +16,13 @@ def run(args: argparse.Namespace):
 
     with network_context(profile.network, cfg.project_name, profile.name):
         shell_globals = load_shell_globals(cfg, profile)
-        with open(args.script_path, encoding="utf-8") as script:
-            exec(script.read(), shell_globals)
+        with open(args.script_path, encoding="utf-8") as file:
+            code = compile(
+                file.read(),
+                os.path.basename(args.script_path),
+                'exec',
+            )
+            exec(code, shell_globals)
 
 
 def add_run_command(parser):
